@@ -6,20 +6,22 @@ Some function will use CUDA kernel. TEST
 #import tools
 import sys
 import datetime
+import numpy as np
+import matplotlib.pyplot as plt
 import gwpy
 import math
 import time
-from numba import cuda
 import numba
-import pyculib
+import cupy
+import astropy
 
+from numba import cuda
 from numba import njit, prange
+
 import cgwpy.tools as tool
+import astropy.coordinates as coord
 
 
-import numpy as np
-import matplotlib.pyplot as plt
-
 from astropy.constants import G
 from astropy import units as u
 from astropy.constants import GM_sun
@@ -28,23 +30,18 @@ from astropy.constants import R_earth
 from astropy.constants import c
 from astropy.constants import au
 from astropy.time import Time
-import astropy.coordinates as coord
+from astropy.coordinates import SkyCoord
 
 from scipy.fft import fft, fftfreq
 from scipy.signal import get_window
 
-import datetime
-import astropy
 from mpl_toolkits import mplot3d
-from astropy.coordinates import SkyCoord
-import astropy.coordinates as coord
 
 from gwpy.time import tconvert
 from gwpy.timeseries import TimeSeries
 
-
-from gwosc.datasets import find_datasets
 from gwosc import datasets
+from gwosc.datasets import find_datasets
 from gwosc.datasets import run_segment
 
 from pprint import pprint
@@ -464,10 +461,20 @@ def signal_correction_algebric(signal_data,S_matrix, R_matrix, T_matrix,  mesh_p
     #C at the end contain every delta_t for each point in 1 column for a specific time.
     #pyculib.blas.Blas.gemm(transa, transb, m, n, k, alpha, A, B, beta, C)
     # utiliser cupy.matmul for matrix multiplication ?
-    pyculib.blas.Blas.gemm(np.transpose(S_matrix), np.transpose(R_matrix), m, n, k, (1/c).value, S_matrix, R_matrix, 1, T_matrix)
+    #pyculib.blas.Blas.gemm(np.transpose(S_matrix), np.transpose(R_matrix), m, n, k, (1/c).value, S_matrix, R_matrix, 1, T_matrix)
+
+    #cupy Version (CUDA kernel)
+    #compute scalar product
+    mult_res=(1/c.value)*cupy.matmul(S_matrix,R_matrix)
+
+    #compute time delay
+    result= T_matrix-mult_res
+
+    #result have same size than T_matrix (360*180*pres)*time
+    return result
+
 
 
-    #save matrix C.
 
 # Can be use CUDA.
 #MUST TO BE in cuda
@@ -510,15 +517,13 @@ def compute_T(matrix_T,t0,f_sampling):
     #thread position
     x,y = cuda.grid(2)
 
-    #verification we are on the array
+    #verification: we are on the array ?
     if(x <= matrix_T.shape[0] and y<= matrix_T.shape[1]):
 
         #compute the time vector
         matrix_T[x][y]= t0 + (y*(1/f_sampling))
 
 
-
-
 # cuda version of T matrix
 # -matrix result cant be superiro at 40 Go.
 # -Must to find solution ( Stream ?)
